Type: Package
Package: rbioapi
Title: User-Friendly R Interface to Biologic Web Services' API
Version: 0.8.3
Authors@R: 
    person(given = "Moosa",
           family = "Rezwani",
           role = c("aut", "cre"),
           email = "moosa.rezwani@gmail.com",
           comment = c(ORCID = "0000-0001-6325-4444")
           )
Description: Currently fully supports Enrichr, JASPAR, miEAA, PANTHER,
    Reactome, STRING, and UniProt! The goal of rbioapi is to provide a
    user-friendly and consistent interface to biological databases and
    services. In a way that insulates the user from the technicalities of
    using web services API and creates a unified and easy-to-use interface
    to biological and medical web services. This is an ongoing project; New
    databases and services will be added periodically. Feel free to
    suggest any databases or services you often use.
License: GPL-3
URL: https://rbioapi.moosa-r.com, https://github.com/moosa-r/rbioapi
BugReports: https://github.com/moosa-r/rbioapi/issues
Imports: httr, jsonlite, utils
Suggests: DT, knitr, png, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-07-02 17:05:55 UTC; moosa
Author: Moosa Rezwani [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6325-4444>)
Maintainer: Moosa Rezwani <moosa.rezwani@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-03 12:50:01 UTC
Built: R 4.6.0; ; 2026-04-26 09:53:26 UTC; unix
